﻿Copyright (c) (2016) Fluke Corporation                      MET/CAL Procedure
=============================================================================
INSTRUMENT:            Tek TDS 220: (1 Year) VER /5500A+SC300
DATE:                  2017-01-27 12:37:24
AUTHOR:                Fluke Corporation
REVISION:              $Revision: 17927 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       3
NUMBER OF LINES:       127
CONFIGURATION:         Fluke 5500A (SC)
=============================================================================
#
# Source:
#   Tektronix TDS 210 & 220 Service Manual 070-9693-04
#
# Overview:
#   This procedure is written to verify the operation of the TDS 2xx
#   Oscilloscopes. This procedure performs a "closed-loop" verification
#   with a minimum of operater intervention.  The following documentation
#   lists the global registers used and subprocedures called.
#
# NUMERIC REGISTERS USED:
#
#   M[10]
#     This register is used to set watchdog timer in the event the
#     oscillscope does not respond to a status command.  THIS REGISTER IS
#     SOMETIMES USED IN THE MAIN PROCEDURE as a Watchdog timer also.
#
#   M[17]
#     This register is used to store the desired resolution of a measurement.
#
#   M[1]
#     This register is used in the Trigger Section of the procedure to store
#     temporary values of MEM.  This section is part of a feedback loop which
#     is used to adjust the 5500 to the proper amplitude.
#
#   M[2]
#     This register is used in the Trigger Section of the procedure to
#     calculate how much the 5500 will be adjusted in the feedback loop.
#
#   M[3]
#     This register is used in the main triggering section to help determine
#     whether the scope is making a correct type of measurement.
#
#   M[4]
#     This register is used to store a value from the -0.600V DC Tests to be
#     to be compared later
#
#   M[100]
#     Channel number
#
#   M[102]
#     Bandwidth in Megahertz (50, 100, 200, or 400)
#
#   M[103]
#     Amplitude (Vpp) for bandwidth tests
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON
  1.001  ASK-         N              P                            F        W
# These statements are here to force the main procedure header to list the
# configuration required by the subprocedures.
  1.002  JMP          1.004
  1.003  5500         1V                                             SC S

# Set timeout for OPC to 30s.
  1.004  MATH         M[88] = 30000

  1.005  RSLT         =
  1.006  HEAD         PRELIMINARY INSTRUCTIONS
  1.007  DISP         Turn the UUT on.
  1.008  EVAL   -s "Self-Test" : Did the power-on self-test pass?

  2.001  JMPT         2.005          Tek TDS 210: (1 Year) VER /5500A+SC300
  2.002  JMPT         2.008          Tek TDS 220: (1 Year) VER /5500A+SC300
  2.003  DISP         Procedure Error
  2.004  END

  2.005  LABEL        60MHZ
  2.006  MATH         M[102] = 60
  2.007  JMPL         SIGNAL_PATH_COMP

  2.008  LABEL        100MHZ
  2.009  MATH         M[102] = 100

  2.010  LABEL        SIGNAL_PATH_COMP
  2.011  DISP         Allow a 10 minute warm-up period before advancing...
  2.012  OPBR         -z It is recommended that a Signal Path Compensation
  2.012  OPBR         Test be performed before running the performance Test.
  2.012  OPBR         It is only necessary to run this test one time.
  2.012  OPBR         Do you want to run the Signal Path Compensation Test?

  2.013  IF           MEM1
  2.014  RSLT         =
  2.015  HEAD         SIGNAL PATH COMPENSATION
  2.016  DISP         Press UTILITY and select Do Self Cal to start the
  2.016  DISP         routine.  Follow the instructions on the UUT screen.
  2.016  DISP         The routine takes approximately one minute to complete.
  2.017  EVAL   -s "Signal Path Compensation Test" : Did Self Cal pass?
  3.001  ENDIF

  3.002  MATH         M[100] = 1
  3.003  PIC          55_2xx_1
  3.004  CALL         Sub TDS2xx (1 yr) DCV /5500+S3
  3.005  JMPL         CH1_ANALOG_BANDWIDTH

  3.006  LABEL        CH2_DC_VOLTAGE
  3.007  MATH         M[100] = 2
  3.008  PIC          55_2xx_2
  3.009  CALL         Sub TDS2xx (1 yr) DCV /5500+S3
  3.010  JMPL         CH2_ANALOG_BANDWIDTH

  3.011  LABEL        CH1_ANALOG_BANDWIDTH
  3.012  PIC          55_2xx1t
  3.013  CALL         Sub TDS2xx (1 yr) Bandwidth /5500+S3
  3.014  JMPL         TIMEBASE_CHECK

  3.015  LABEL        CH2_ANALOG_BANDWIDTH
  3.016  PIC          55_2xx2t
  3.017  CALL         Sub TDS2xx (1 yr) Bandwidth /5500+S3
  3.018  JMPL         CH2_TRIGGER

  3.019  LABEL        TIMEBASE_CHECK
  3.020  CALL         Sub TDS2xx (1 yr) Timebase /5500+S3
  3.021  CALL         Sub TDS2xx (1 yr) Trigger /5500+S3
  3.022  JMPL         CH2_DC_VOLTAGE

  3.023  LABEL        CH2_TRIGGER
  3.024  CALL         Sub TDS2xx (1 yr) Trigger /5500+S3

  3.025  MATH         M[100] = 1
  3.026  PIC          55_2xx_e
  3.027  CALL         Sub TDS2xx (1 yr) Ext Trig /5500+S3
  3.028  END
